"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const common_1 = require("@nestjs/common");
const __1 = require("..");
const logging_1 = require("../gcloud/logging");
const auth_configurer_1 = require("./auth.configurer");
const auth_guard_1 = require("./auth.guard");
const auth_listener_1 = require("./auth.listener");
let AuthController = class AuthController {
    constructor(authConfigurer, inviteUserService, configuration, authListener) {
        this.authConfigurer = authConfigurer;
        this.inviteUserService = inviteUserService;
        this.configuration = configuration;
        this.authListener = authListener;
        this.logger = logging_1.createLogger('auth-controller');
    }
    signIn(req, res, next) {
        this.authConfigurer.authenticateLocal()(req, res, (result) => {
            if (result) {
                if (result instanceof common_1.HttpException) {
                    return res.status(result.getStatus()).send(result.getResponse());
                }
                next(result);
            }
            else {
                this.authListener.onLogin(req);
                res.send({
                    result: 'success',
                });
            }
        });
    }
    signInFake(req, res, next) {
        this.authConfigurer.authenticateFake()(req, res, (result) => {
            if (result) {
                if (result instanceof common_1.HttpException) {
                    return res.status(result.getStatus()).send(result.getResponse());
                }
                next(result);
            }
            else {
                this.authListener.onLogin(req);
                res.send({
                    result: 'success',
                });
            }
        });
    }
    async activate(req, res, next, context) {
        await this.inviteUserService.activateAccount(context, req.body.code, req.body.name, req.body.password);
        res.send({
            result: 'Activated successfully',
        });
    }
    async reInviteUser(req, res, next, context) {
        if (!req.body.userId) {
            throw new Error('User id not supplied');
        }
        this.logger.info('Re invite requested for ' + req.body.userId);
        const userInviteResponse = await this.inviteUserService.reInviteForUserId(context, req.body.userId);
        if (userInviteResponse) {
            res.send({
                result: 'Re Invited user successfully',
            });
        }
        else {
            res.status(common_1.HttpStatus.INTERNAL_SERVER_ERROR).send('Error while re inviting user');
        }
    }
    signOutLocal(req, res, next) {
        this.logger.debug('Logging out local user');
        req.logout();
        if (req.xhr) {
            res.status(204).send();
        }
        else {
            const redirectUrl = '/';
            this.logger.debug(`Redirecting to ${redirectUrl} for non-xhr request`);
            res.redirect(redirectUrl);
        }
    }
    signOut(req, res, next) {
        this.logger.warn('This endpoint is deprecated and will be removed in future releases - please use GET /auth/signout/local instead');
        req.logout();
        res.redirect('/');
    }
    signInGoogle(req, res, next) {
        this.authConfigurer.beginAuthenticateGoogle()(req, res, next);
    }
    completeSignInGoogle(req, res) {
        this.authConfigurer.completeAuthenticateGoogle()(req, res, (err) => {
            if (req.user) {
                this.authListener.onLogin(req);
                res.redirect(`/`);
            }
            else {
                this.logger.warn('Login with google failed', err);
                res.redirect(`/signin?error=${encodeURIComponent('Login with google failed.')}`);
            }
        });
    }
    signInSaml(req, res, next) {
        this.logger.info('Redirecting to SAML Identity Provider');
        this.authConfigurer.beginAuthenticateSaml()(req, res, next);
    }
    completeSignInSaml(req, res) {
        this.logger.info('Received ACS callback from SAML Identity Provider');
        this.authConfigurer.completeAuthenticateSaml()(req, res, (err) => {
            if (req.user) {
                this.logger.info('user: %o', req.user);
                this.authListener.onLogin(req);
                res.redirect('/');
            }
            else {
                this.logger.warn('Login with SAML failed', err);
                res.redirect(`/signin?error=${encodeURIComponent('Login with SAML failed.')}`);
            }
        });
    }
    signInAuth0(req, res, next) {
        this.authConfigurer.beginAuthenticateAuth0()(req, res, next);
    }
    signOutAuth0(req, res) {
        const redirectUrl = this.authConfigurer.getSignoutUrlAuth0();
        this.logger.info('Redirecting to ', redirectUrl);
        res.redirect(redirectUrl);
    }
    completeSignInAuth0(req, res) {
        this.authConfigurer.completeAuthenticateAuth0()(req, res, (err) => {
            if (req.user) {
                this.authListener.onLogin(req);
                res.redirect(`/`);
            }
            else {
                this.logger.warn('Login with auth0 failed', err);
                res.redirect(`/signin?error=${encodeURIComponent('Login with auth0 failed.')}`);
            }
        });
    }
    signInOidc(req, res, next) {
        this.authConfigurer.beginAuthenticateOidc()(req, res, next);
    }
    completeSignInOidc(req, res) {
        this.authConfigurer.completeAuthenticateOidc()(req, res, (err) => {
            if (req.user) {
                this.authListener.onLogin(req);
                res.redirect(`/`);
            }
            else {
                this.logger.warn('Login with oidc failed', err);
                res.redirect(`/signin?error=${encodeURIComponent('Login with oidc failed.')}`);
            }
        });
    }
};
tslib_1.__decorate([
    auth_guard_1.AllowAnonymous(),
    common_1.Post('signin/local'),
    tslib_1.__param(0, common_1.Req()), tslib_1.__param(1, common_1.Res()), tslib_1.__param(2, common_1.Next()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object, Object, Function]),
    tslib_1.__metadata("design:returntype", void 0)
], AuthController.prototype, "signIn", null);
tslib_1.__decorate([
    auth_guard_1.AllowAnonymous(),
    common_1.Post('signin/fake'),
    tslib_1.__param(0, common_1.Req()), tslib_1.__param(1, common_1.Res()), tslib_1.__param(2, common_1.Next()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object, Object, Function]),
    tslib_1.__metadata("design:returntype", void 0)
], AuthController.prototype, "signInFake", null);
tslib_1.__decorate([
    auth_guard_1.AllowAnonymous(),
    common_1.Post('activate'),
    tslib_1.__param(0, common_1.Req()),
    tslib_1.__param(1, common_1.Res()),
    tslib_1.__param(2, common_1.Next()),
    tslib_1.__param(3, __1.Ctxt()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object, Object, Function, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], AuthController.prototype, "activate", null);
tslib_1.__decorate([
    auth_guard_1.Roles('admin'),
    common_1.Post('re-invite'),
    tslib_1.__param(0, common_1.Req()),
    tslib_1.__param(1, common_1.Res()),
    tslib_1.__param(2, common_1.Next()),
    tslib_1.__param(3, __1.Ctxt()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object, Object, Function, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], AuthController.prototype, "reInviteUser", null);
tslib_1.__decorate([
    auth_guard_1.AllowAnonymous(),
    common_1.Get('signout/local'),
    tslib_1.__param(0, common_1.Req()), tslib_1.__param(1, common_1.Res()), tslib_1.__param(2, common_1.Next()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object, Object, Function]),
    tslib_1.__metadata("design:returntype", void 0)
], AuthController.prototype, "signOutLocal", null);
tslib_1.__decorate([
    common_1.Post('signout/local'),
    tslib_1.__param(0, common_1.Req()), tslib_1.__param(1, common_1.Res()), tslib_1.__param(2, common_1.Next()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object, Object, Function]),
    tslib_1.__metadata("design:returntype", void 0)
], AuthController.prototype, "signOut", null);
tslib_1.__decorate([
    auth_guard_1.AllowAnonymous(),
    common_1.Get('signin/google'),
    tslib_1.__param(0, common_1.Req()), tslib_1.__param(1, common_1.Res()), tslib_1.__param(2, common_1.Next()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object, Object, Function]),
    tslib_1.__metadata("design:returntype", void 0)
], AuthController.prototype, "signInGoogle", null);
tslib_1.__decorate([
    auth_guard_1.AllowAnonymous(),
    common_1.Get('signin/google/callback'),
    tslib_1.__param(0, common_1.Req()), tslib_1.__param(1, common_1.Res()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object, Object]),
    tslib_1.__metadata("design:returntype", void 0)
], AuthController.prototype, "completeSignInGoogle", null);
tslib_1.__decorate([
    auth_guard_1.AllowAnonymous(),
    common_1.Get('signin/saml'),
    tslib_1.__param(0, common_1.Req()), tslib_1.__param(1, common_1.Res()), tslib_1.__param(2, common_1.Next()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object, Object, Function]),
    tslib_1.__metadata("design:returntype", void 0)
], AuthController.prototype, "signInSaml", null);
tslib_1.__decorate([
    auth_guard_1.AllowAnonymous(),
    common_1.Post('signin/saml/acs'),
    tslib_1.__param(0, common_1.Req()), tslib_1.__param(1, common_1.Res()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object, Object]),
    tslib_1.__metadata("design:returntype", void 0)
], AuthController.prototype, "completeSignInSaml", null);
tslib_1.__decorate([
    auth_guard_1.AllowAnonymous(),
    common_1.Get('signin/auth0'),
    tslib_1.__param(0, common_1.Req()), tslib_1.__param(1, common_1.Res()), tslib_1.__param(2, common_1.Next()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object, Object, Function]),
    tslib_1.__metadata("design:returntype", void 0)
], AuthController.prototype, "signInAuth0", null);
tslib_1.__decorate([
    auth_guard_1.AllowAnonymous(),
    common_1.Get('signout/auth0'),
    tslib_1.__param(0, common_1.Req()), tslib_1.__param(1, common_1.Res()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object, Object]),
    tslib_1.__metadata("design:returntype", void 0)
], AuthController.prototype, "signOutAuth0", null);
tslib_1.__decorate([
    auth_guard_1.AllowAnonymous(),
    common_1.Get('signin/auth0/callback'),
    tslib_1.__param(0, common_1.Req()), tslib_1.__param(1, common_1.Res()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object, Object]),
    tslib_1.__metadata("design:returntype", void 0)
], AuthController.prototype, "completeSignInAuth0", null);
tslib_1.__decorate([
    auth_guard_1.AllowAnonymous(),
    common_1.Get('signin/oidc'),
    tslib_1.__param(0, common_1.Req()), tslib_1.__param(1, common_1.Res()), tslib_1.__param(2, common_1.Next()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object, Object, Function]),
    tslib_1.__metadata("design:returntype", void 0)
], AuthController.prototype, "signInOidc", null);
tslib_1.__decorate([
    auth_guard_1.AllowAnonymous(),
    common_1.Get('signin/oidc/callback'),
    tslib_1.__param(0, common_1.Req()), tslib_1.__param(1, common_1.Res()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object, Object]),
    tslib_1.__metadata("design:returntype", void 0)
], AuthController.prototype, "completeSignInOidc", null);
AuthController = tslib_1.__decorate([
    common_1.Controller('auth'),
    tslib_1.__param(2, common_1.Inject('Configuration')),
    tslib_1.__param(3, common_1.Inject(auth_listener_1.AUTH_LISTENER)),
    tslib_1.__metadata("design:paramtypes", [auth_configurer_1.AuthConfigurer,
        __1.InviteUserService, Object, Object])
], AuthController);
exports.AuthController = AuthController;
//# sourceMappingURL=auth.controller.js.map