import * as t from 'io-ts';
import { Context } from '..';
import { DatastoreProvider } from '../datastore/datastore.provider';
import { Repository } from '../datastore/repository';
import { OneOrMany } from '../util/types';
declare const passwordReset: t.TypeC<{
    id: t.StringC;
    accountId: t.StringC;
    createdAt: t.Type<Date, Date, unknown>;
}>;
export declare type PasswordReset = t.TypeOf<typeof passwordReset>;
export declare class PasswordResetRepository extends Repository<PasswordReset> {
    constructor(datastoreProvider: DatastoreProvider);
}
declare const userInvite: t.TypeC<{
    id: t.StringC;
    email: t.StringC;
    createdAt: t.Type<Date, Date, unknown>;
    userId: t.StringC;
    roles: t.ArrayC<t.StringC>;
}>;
export declare type UserInvite = t.TypeOf<typeof userInvite>;
export declare class UserInviteRepository extends Repository<UserInvite> {
    constructor(datastoreProvider: DatastoreProvider);
}
declare const externalAuthTypeEnum: t.UnionC<[t.LiteralC<"google">, t.LiteralC<"saml">, t.LiteralC<"auth0">, t.LiteralC<"oidc">]>;
declare const loginCredentials: t.Type<{
    id: string;
    userId: string;
    password: string;
    type: "password";
} | {
    id: string;
    userId: string;
    type: "google" | "saml" | "auth0" | "oidc";
}, {
    id: string;
    userId: string;
    password: string;
    type: "password";
} | {
    id: string;
    userId: string;
    type: "google" | "saml" | "auth0" | "oidc";
}, unknown>;
export declare type LoginCredentials = t.TypeOf<typeof loginCredentials>;
export declare type ExternalAuthType = t.TypeOf<typeof externalAuthTypeEnum>;
export declare class CredentialRepository extends Repository<LoginCredentials> {
    constructor(datastore: DatastoreProvider);
    protected beforePersist(context: Context, entities: OneOrMany<LoginCredentials>): OneOrMany<LoginCredentials>;
}
export {};
