import { HttpException } from '@nestjs/common';
import { Configuration, Context, IUser } from '..';
import { CredentialRepository, LoginCredentials } from './auth.repository';
import { UserService } from './user.service';
export declare class AuthenticationFailedException extends HttpException {
    constructor(message: string);
}
export declare function hashPassword(password: string): Promise<string>;
export declare class AuthService {
    private readonly authRepository;
    private readonly userService;
    private readonly configurationProvider;
    private readonly logger;
    constructor(authRepository: CredentialRepository, userService: UserService<IUser>, configurationProvider: Configuration);
    validateUser(context: Context, username: string, password: string): Promise<IUser>;
    validateFakeLogin(context: Context, secret: string | string[] | undefined, email: string, name: string, roles: string[], orgId: string, props: any): Promise<IUser>;
    validateUserGoogle(context: Context, inputProfile: object): Promise<IUser>;
    validateUserSaml(context: Context, profile: SimpleUserProfile): Promise<IUser>;
    validateUserOidc(context: Context, profile: any, overwriteCredentials: boolean, newUserRoles?: string[]): Promise<IUser>;
    validateUserAuth0(context: Context, email: string, name: string, orgId: string, roles: string[], props: any): Promise<IUser>;
    createAccount(context: Context, email: string, password: string, account: string): Promise<LoginCredentials>;
    private validateOrCreateExternalAuthAccount;
    private loadUserAndCheckEnabled;
    private validateUserEnabled;
    private getAccountByEmail;
    private toName;
}
export interface SimpleUserProfile {
    email: string;
    firstName?: string;
    lastName?: string;
}
