import { Context, IUser } from '../datastore/context';
import { Configuration, MailSender, UserService } from '../index';
import { CredentialRepository, UserInviteRepository } from './auth.repository';
export declare const DEFAULT_INVITE_CODE_EXPIRY: number;
export interface IInviteUserResponse {
    user: IUser;
    inviteId?: string;
    activateLink?: string;
}
export interface IInviteUserRequest {
    email: string;
    roles: string[];
    name?: string;
    skipEmail?: boolean;
}
export declare class InviteUserService {
    private readonly authRepository;
    private readonly mailSender;
    private readonly configuration;
    private readonly userService;
    private readonly userInviteRepository;
    private readonly logger;
    constructor(authRepository: CredentialRepository, mailSender: MailSender, configuration: Configuration, userService: UserService<IUser>, userInviteRepository: UserInviteRepository);
    inviteUserIfRequired(context: Context, request: IInviteUserRequest): Promise<IInviteUserResponse>;
    inviteUser(context: Context, request: IInviteUserRequest): Promise<IInviteUserResponse>;
    getInvitedUser(context: Context, code: string): Promise<IUser | undefined>;
    reInviteForUserId(context: Context, userId: string): Promise<IInviteUserResponse>;
    getUserInviteForUserId(context: Context, userId: string): Promise<{
        id: string;
        email: string;
        createdAt: Date;
        userId: string;
        roles: string[];
    } | undefined>;
    protected reInviteUser(context: Context, existingInvite: any): Promise<IInviteUserResponse>;
    protected inviteUserInternal(context: Context, request: IInviteUserRequest, validateNew: boolean): Promise<IInviteUserResponse>;
    private getActivationExpiryInMillis;
    private getActivationExpiryEmailCopy;
    private getInvitationCopy;
    private sendActivationEmail;
    checkActivationCode(context: Context, code: string): Promise<string | null>;
    activateAccount(context: Context, code: string, name: string, password: string): Promise<IUser>;
    private checkInvite;
}
