"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const common_1 = require("@nestjs/common");
const lodash_1 = require("lodash");
const configuration_1 = require("../configuration");
const logging_1 = require("../gcloud/logging");
let MailSubjectSender = class MailSubjectSender {
    constructor(mailSender, configurationProvider) {
        this.mailSender = mailSender;
        this.configurationProvider = configurationProvider;
        this.logger = logging_1.createLogger('mail-subject-sender');
        const { devHooks } = this.configurationProvider;
        if (!devHooks || lodash_1.isEmpty(devHooks.emailSubjectPrefix)) {
            throw new Error('No subject prefix defined');
        }
        this.subjectPrefix = `${devHooks.emailSubjectPrefix}: `;
        this.logger.info(`Configuring mail with subject prefix '${this.subjectPrefix}'`);
    }
    async send(context, mailOptions) {
        const subject = `${this.subjectPrefix}${mailOptions.subject}`;
        this.logger.info(`Sending email with prefixed subject: '${subject}'`);
        return this.mailSender.send(context, Object.assign({}, mailOptions, { subject }));
    }
};
MailSubjectSender = tslib_1.__decorate([
    common_1.Injectable(),
    tslib_1.__param(1, common_1.Inject(configuration_1.CONFIGURATION)),
    tslib_1.__metadata("design:paramtypes", [Object, Object])
], MailSubjectSender);
exports.MailSubjectSender = MailSubjectSender;
//# sourceMappingURL=mail-subject.sender.js.map