"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const common_1 = require("@nestjs/common");
const node_fetch_1 = require("node-fetch");
const __1 = require("..");
const isPredicate = (value) => {
    return value.op !== undefined;
};
const isPredicateArray = (value) => {
    return Array.isArray(value) && value.length > 0 && isPredicate(value[0]);
};
let GaeSearchService = class GaeSearchService extends __1.SearchService {
    constructor(configuration) {
        super();
        this.configuration = configuration;
        this.logger = __1.createLogger('search-service');
    }
    index(entityName, entries) {
        this.logger.info(`Indexing ${entries.length} ${entityName} entities`);
        return this.post('/index', {
            entityName,
            entries,
        });
    }
    delete(entityName, ...ids) {
        return this.post('/delete', {
            entityName,
            ids,
        });
    }
    deleteAll(entityName) {
        return this.post('/deleteAll', {
            entityName,
        });
    }
    async query(entityName, fields, sort, page) {
        const resp = await this.post('/query', {
            entityName,
            fields: this.normaliseFields(fields),
            sort,
            page,
        });
        const queryResults = await resp.json();
        this.logger.info(`Query returned ${queryResults.ids.length} ids of total ${queryResults.resultCount}`);
        return queryResults;
    }
    post(path, body) {
        if (!this.configuration.searchServiceEndpoint) {
            throw new Error('searchServiceEndpoint must be configured in order to use the SearchService');
        }
        return node_fetch_1.default(this.configuration.searchServiceEndpoint + path, {
            method: 'POST',
            body: JSON.stringify(body),
        });
    }
    normaliseFields(fields) {
        return Object.keys(fields).reduce((result, key) => {
            const field = fields[key];
            if (isPredicateArray(field)) {
                field.forEach(predicate => result.push(this.toSearchPredicate(key, predicate)));
            }
            else {
                result.push(this.toSearchPredicate(key, field));
            }
            return result;
        }, []);
    }
    toSearchPredicate(fieldName, input) {
        return isPredicate(input)
            ? {
                field: fieldName,
                op: input.op,
                value: input.value,
            }
            : {
                field: fieldName,
                op: '=',
                value: input,
            };
    }
};
GaeSearchService = tslib_1.__decorate([
    common_1.Injectable(),
    tslib_1.__param(0, common_1.Inject(__1.CONFIGURATION)),
    tslib_1.__metadata("design:paramtypes", [Object])
], GaeSearchService);
exports.GaeSearchService = GaeSearchService;
//# sourceMappingURL=gae-search.service.js.map