import { Response } from 'node-fetch';
import { Configuration } from '..';
interface IndexEntry {
    id: string;
    fields: {
        [key: string]: string;
    };
}
export interface Sort {
    field: string;
    descending?: boolean;
}
export interface Page {
    limit: number;
    offset: number;
}
export interface QueryResults {
    resultCount: number;
    limit: number;
    offset: number;
    ids: string[];
}
export interface SearchResults<T> {
    resultCount: number;
    limit: number;
    offset: number;
    results: ReadonlyArray<T> | undefined;
}
export declare type Operator = '=' | '!=' | '>' | '<' | '>=' | '<=';
export interface SearchFields {
    [key: string]: string | string[] | Predicate | Predicate[];
}
export interface Predicate {
    op: Operator;
    value: string | string[] | number | Date;
}
export interface SearchPredicate extends Predicate {
    field: string;
}
export declare class SearchService {
    private readonly configuration;
    private logger;
    constructor(configuration: Configuration);
    index(entityName: string, entries: IndexEntry[]): Promise<Response>;
    delete(entityName: string, ...ids: string[]): Promise<Response>;
    deleteAll(entityName: string): Promise<Response>;
    query(entityName: string, fields: SearchFields, sort?: Sort, page?: Page): Promise<QueryResults>;
    private post;
    private normaliseFields;
    private toSearchPredicate;
}
export {};
