import { Datastore } from '@google-cloud/datastore';
import * as t from 'io-ts';
import { Context } from '../datastore/context';
import { Index } from '../datastore/loader';
import { Repository, RepositoryOptions } from '../datastore/repository';
import { Omit } from '../util/types';
import { Page, SearchFields, SearchResults, SearchService, Sort } from './search.service';
interface SearchableRepositoryOptions<T extends {
    id: any;
}> extends RepositoryOptions<T> {
    searchIndex: Index<Omit<T, 'id'>>;
}
export declare class SearchableRepository<T extends {
    id: string;
}> extends Repository<T> {
    protected readonly searchService: SearchService;
    protected readonly options: SearchableRepositoryOptions<T>;
    private baseLogger;
    constructor(datastore: Datastore, searchService: SearchService, kind: string, validator: t.Type<T>, options: SearchableRepositoryOptions<T>);
    save(context: Context, entities: T): Promise<T>;
    save(context: Context, entities: ReadonlyArray<T>): Promise<ReadonlyArray<T>>;
    update(context: Context, entities: T): Promise<T>;
    update(context: Context, entities: ReadonlyArray<T>): Promise<ReadonlyArray<T>>;
    insert(context: Context, entities: T): Promise<T>;
    insert(context: Context, entities: ReadonlyArray<T>): Promise<ReadonlyArray<T>>;
    upsert(context: Context, entities: T): Promise<T>;
    upsert(context: Context, entities: ReadonlyArray<T>): Promise<ReadonlyArray<T>>;
    delete(context: Context, ...ids: string[]): Promise<void>;
    deleteAll(context: Context): Promise<void>;
    search(context: Context, searchFields: SearchFields, sort?: Sort): Promise<readonly T[]>;
    searchWithPagination(context: Context, searchFields: SearchFields, sort?: Sort, page?: Page): Promise<SearchResults<T>>;
    private index;
    private fetchResults;
}
export {};
